==> speech-analytic-testing_3.6.0_database.tar.gz: database/mssql/procedures/GetAudio.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetAudio] (
	@VCC Varchar(50) = NULL,
	@ProcessId Varchar(50) = NULL,
	@ID Varchar(100) = NULL,
	@Section NUMERIC(5, 0) NULL,
	@Part NUMERIC(5, 0) NULL
)
AS
BEGIN
	SET NOCOUNT ON

	SELECT TOP 1
		A.[ID]						'id',
		A.[Section]					'section',
		A.[Part]					'part',
		PA.[ProcessId]				'processId',
		A.[Number]					'number',
		A.[Gender]					'gender',
		A.[SilenceTime]				'silenceTime',
		A.[DurationTime]			'durationTime',
		A.[DurationLinguisticTime]	'durationLinguisticTime',
		A.[Category1]				'category1',
		A.[Category2]				'category2',
		A.[Category3]				'category3',
		A.[Description]				'description',
		A.[Campaign]				'campaign',
		A.[Agent]					'agent',
		A.[Type]					'type',
		A.[Init]					'init',
		A.[ChannelsChanged]			'channelsChanged',
		A.[IsTranscribed]			'isTranscribed',
		A.[RelativePath]			'relativePath',
		A.[FileName]				'fileName',
		P.[Retranscription]			'retranscription'
	FROM [Audio] A (NOLOCK)
	LEFT JOIN [ProcessAudio] PA (NOLOCK)
		ON PA.[VCC] = A.[VCC]
			AND A.ID = PA.AudioId 
			AND A.Section = PA.Section 
			AND A.Part = PA.Part
	LEFT JOIN [dbo].[Process] P (NOLOCK)
		ON P.[VCC] = A.[VCC]
			AND PA.[ProcessId] = P.[Name]
	WHERE A.[VCC] = @VCC
		AND (
			(@ProcessId IS NOT NULL AND P.[Name] = @ProcessId)
			OR 
			(@ProcessId IS NULL)
		)
		AND A.[ID] = @ID
		AND A.[Section] = @Section
		AND A.[Part] = @Part
		AND A.[IsTranscribed] = 1
		AND A.[IsCancel] IS NULL
		AND P.[Name] IS NOT NULL
	ORDER BY A.CreatedDate DESC, PA.[CreatedDate] DESC

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_5.2.11_database.tar.gz: database/mssql/procedures/GetAudio.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetAudio] (
	@VCC Varchar(50) = NULL,
	@ProcessId Varchar(50) = NULL,
	@ID Varchar(100) = NULL,
	@Section NUMERIC(5, 0) NULL,
	@Part NUMERIC(5, 0) NULL
)
AS
BEGIN
	SET NOCOUNT ON

	SELECT TOP 1
		A.[ID]						'id',
		A.[Section]					'section',
		A.[Part]					'part',
		PA.[ProcessId]				'processId',
		A.[Number]					'number',
		A.[Gender]					'gender',
		A.[SilenceTime]				'silenceTime',
		A.[DurationTime]			'durationTime',
		A.[DurationLinguisticTime]	'durationLinguisticTime',
		A.[Category1]				'category1',
		A.[Category2]				'category2',
		A.[Category3]				'category3',
		A.[Description]				'description',
		A.[Campaign]				'campaign',
		A.[Agent]					'agent',
		A.[Type]					'type',
		A.[Init]					'init',
		A.[ChannelsChanged]			'channelsChanged',
		A.[IsTranscribed]			'isTranscribed',
		A.[RelativePath]			'relativePath',
		A.[FileName]				'fileName',
		P.[Retranscription]			'retranscription',
		A.[RelativeFileName]		'relativeFileName'
	FROM [Audio] A (NOLOCK)
	LEFT JOIN [ProcessAudio] PA (NOLOCK)
		ON PA.[VCC] = A.[VCC]
			AND A.ID = PA.AudioId 
			AND A.Section = PA.Section 
			AND A.Part = PA.Part
	LEFT JOIN [dbo].[Process] P (NOLOCK)
		ON P.[VCC] = A.[VCC]
			AND PA.[ProcessId] = P.[Name]
	WHERE A.[VCC] = @VCC
		AND (
			(@ProcessId IS NOT NULL AND P.[Name] = @ProcessId)
			OR 
			(@ProcessId IS NULL)
		)
		AND A.[ID] = @ID
		AND A.[Section] = @Section
		AND A.[Part] = @Part
		AND A.[IsTranscribed] = 1
		AND A.[IsCancel] IS NULL
		AND P.[Name] IS NOT NULL
	ORDER BY A.CreatedDate DESC, PA.[CreatedDate] DESC

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
